package asChat

import (
	"fonchain-fiee/api/accountFiee"
	"fonchain-fiee/pkg/service"
	"fonchain-fiee/pkg/utils"
	"github.com/gin-gonic/gin"
)

var Handler = &ChatAutoReplyRulerHandler{}

type ChatAutoReplyRulerHandler struct {
}

// 创建自动回复规则
func (a *ChatAutoReplyRulerHandler) CreateChatAutoReplyRuler(c *gin.Context) {
	var req accountFiee.ChatAutoReplyRulerData
	if err := c.ShouldBindJSON(&req); err != nil {
		service.Error(c, err)
		return
	}
	_, err := service.AccountFieeProvider.CreateChatAutoReplyRuler(c, &req)
	if err != nil {
		service.Error(c, err)
		return
	}
	service.Success(c)
}

// 删除自动回复规则
func (a *ChatAutoReplyRulerHandler) DeleteChatAutoReplyRuler(c *gin.Context) {
	var req accountFiee.DeleteChatAutoReplyRulerRequest
	if err := c.ShouldBindJSON(&req); err != nil {
		service.Error(c, err)
		return
	}
	_, err := service.AccountFieeProvider.DeleteChatAutoReplyRuler(c, &req)
	if err != nil {
		service.Error(c, err)
		return
	}
	service.Success(c)
}

// 更新自动回复规则
func (a *ChatAutoReplyRulerHandler) UpdateChatAutoReplyRuler(c *gin.Context) {
	var req accountFiee.ChatAutoReplyRulerData
	if err := c.ShouldBindJSON(&req); err != nil {
		service.Error(c, err)
		return
	}
	_, err := service.AccountFieeProvider.UpdateChatAutoReplyRuler(c, &req)
	if err != nil {
		service.Error(c, err)
		return
	}
	service.Success(c)
}

// 使用id查询自动回复规则
func (a *ChatAutoReplyRulerHandler) GetChatAutoReplyRulerDetail(c *gin.Context) {
	var req accountFiee.GetChatAutoReplyRulerByIdRequest
	if err := c.ShouldBindJSON(&req); err != nil {
		service.Error(c, err)
		return
	}
	resp, err := service.AccountFieeProvider.GetChatAutoReplyRulerDetail(c, &req)
	if err != nil {
		service.Error(c, err)
		return
	}
	service.Success(c, resp)
}

// 批量查询自动回复规则
func (a *ChatAutoReplyRulerHandler) GetChatAutoReplyRulerList(c *gin.Context) {
	var req GetChatAutoReplyRulerListRequest
	if err := c.ShouldBindJSON(&req); err != nil {
		service.Error(c, err)
		return
	}
	var protoReq = accountFiee.GetChatAutoReplyRulerListRequest{Query: &accountFiee.ChatAutoReplyRulerData{}}
	utils.RequestDataConvert(&req, &protoReq)
	resp, err := service.AccountFieeProvider.GetChatAutoReplyRulerList(c, &protoReq)
	if err != nil {
		service.Error(c, err)
		return
	}
	service.Success(c, resp.List)
}
